velruse.utils — Velruse 1.1 documentation

### Navigation

- index
- modules |
- Velruse 1.1 documentation »
- Module code »
- velruse »

# Source code for velruse.utils

    """Utilities for the auth functionality"""
    import urllib

    def flat_url(url, **kw):
        """Creates a URL with the query param encoded"""
        url += '?' + urllib.urlencode(kw)
        return url

### Navigation

- index
- modules |
- Velruse 1.1 documentation »
- Module code »
- velruse »